package com.fs.hisStore.mapper;

import com.fs.hisStore.domain.FsStoreRecommendScrm;
import java.util.List;

/**
 * 店铺推荐Mapper接口
 *
 * @author fs
 * @date 2023-06-15
 */
public interface FsStoreRecommendScrmMapper
{
    /**
     * 查询店铺推荐
     *
     * @param id 店铺推荐主键
     * @return 店铺推荐
     */
    public FsStoreRecommendScrm selectFsStoreRecommendScrmById(Long id);

    /**
     * 查询店铺推荐列表
     *
     * @param fsStoreRecommendScrm 店铺推荐
     * @return 店铺推荐集合
     */
    public List<FsStoreRecommendScrm> selectFsStoreRecommendScrmList(FsStoreRecommendScrm fsStoreRecommendScrm);

    /**
     * 查询有效的推荐店铺列表(根据时间、状态等条件)
     *
     * @param fsStoreRecommendScrm 店铺推荐
     * @return 店铺推荐集合
     */
    public List<FsStoreRecommendScrm> selectValidRecommendList(FsStoreRecommendScrm fsStoreRecommendScrm);

    /**
     * 新增店铺推荐
     *
     * @param fsStoreRecommendScrm 店铺推荐
     * @return 结果
     */
    public int insertFsStoreRecommendScrm(FsStoreRecommendScrm fsStoreRecommendScrm);

    /**
     * 修改店铺推荐
     *
     * @param fsStoreRecommendScrm 店铺推荐
     * @return 结果
     */
    public int updateFsStoreRecommendScrm(FsStoreRecommendScrm fsStoreRecommendScrm);

    /**
     * 删除店铺推荐
     *
     * @param id 店铺推荐主键
     * @return 结果
     */
    public int deleteFsStoreRecommendScrmById(Long id);

    /**
     * 批量删除店铺推荐
     *
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteFsStoreRecommendScrmByIds(Long[] ids);
}
